@@ -264,7 +264,9 @@ cell2str_and_size(lex_ctxt* lexic, tree_cell* c, int * sz)
 }
 #endif
 
-/* cell2atom returns a 'referenced' cell */	
+/**
+ * @return A 'referenced' cell.
+ */
 tree_cell*
 cell2atom(lex_ctxt* lexic, tree_cell* c1)
 {
@@ -1707,13 +1709,32 @@ nasl_exec(lex_ctxt* lexic, tree_cell* st)
 extern tree_cell*	nasl_lint(lex_ctxt*, tree_cell*);
 
 /**
- * @param script_infos The lpugin as arglist. Has to be allocated, and at least
+ * @brief This method is deprecated. Use @ref exec_nasl_script
+ *        This function can be removed with the next major
+ *        release after 2.0.
+ *
+ * @param script_infos The plugin as arglist. Has to be allocated, and at least
  *                     "preferences" sould be set.
- * @param
  * @return Values < 0 
  */
 int
 execute_nasl_script(struct arglist * script_infos, const char* name, const char * cache_dir, int mode)
+{
+  return exec_nasl_script(script_infos, name, mode);
+}
+
+/**
+ * @brief Execute a NASL script.
+ *
+ * @param script_infos The lpugin as arglist. Has to be allocated, and at least
+ *                     "preferences" sould be set.
+ * @param name
+ * @param mode
+ *
+ * @return Values < 0 
+ */
+int
+exec_nasl_script(struct arglist * script_infos, const char* name, int mode)
 {
   naslctxt	ctx;
   nasl_func	*pf;
@@ -1727,7 +1748,6 @@ execute_nasl_script(struct arglist * script_infos, const char* name, const char
   struct arglist*	prefs = arg_get_value(script_infos, "preferences");
   char		*str;
   int		to;
-  char * basename;
 
   srand48(getpid() + getppid() + (long)time(NULL));
 
@@ -1754,15 +1774,13 @@ execute_nasl_script(struct arglist * script_infos, const char* name, const char
 	 s = strrchr(dir, '/');
 	 s[0] = '\0';
 	 chdir(dir);
-	 basename = newdir + 1;
  }
- else basename = (char*)name;
 
  bzero(&ctx, sizeof(ctx));
  if ( mode & NASL_ALWAYS_SIGNED )
 	ctx.always_authenticated = 1;
  
- if (nasl_load_or_parse(&ctx, name, basename, cache_dir) < 0 )
+ if (nasl_reload_or_parse(&ctx, name) < 0 )
   {
     chdir(old_dir);
     return -1;
@@ -1858,5 +1876,3 @@ execute_nasl_script(struct arglist * script_infos, const char* name, const char
 
  return err;
 }
-
-
