@@ -17,12 +17,12 @@
  *
  *
  */
- 
- /**
-  * @file
-  * Source of the standalone NASL interpreter of OpenVAS.
-  */
- 
+
+/**
+ * @file
+ * Source of the standalone NASL interpreter of OpenVAS.
+ */
+
 #include <includes.h>
 #include <hosts_gatherer.h>
 
@@ -108,7 +108,10 @@ int main(int argc, char ** argv)
  gchar * default_target = "127.0.0.1";
  struct hg_globals * hg_globals;
  struct in_addr ip;
- int start, n; 
+ int start;
+ int n;
+/* Flawfinder: ignore, hostname is passed to hg_next_host which might pass it to
+ hg_get_name_from_ip. Both respect the given (and correct) size. */
  char hostname[1024];
  int	mode = 0;
  int	err = 0;
