@@ -75,6 +75,7 @@ static init_func libfuncs[] = {
   { "script_dependencie", script_dependencie, 999, { NULL } },
   { "script_dependencies",script_dependencie, 999, { NULL } },
   { "script_require_keys",script_require_keys, 999, { NULL } },
+  { "script_mandatory_keys",script_mandatory_keys, 999, { NULL } },
   { "script_require_ports", script_require_ports, 999,  { NULL } },
   { "script_require_udp_ports", script_require_udp_ports, 999, { NULL } },
   { "script_exclude_keys", script_exclude_keys, 999, { NULL } },
@@ -329,7 +330,7 @@ static struct {
   { "ENCAPS_SSLv3",  NESSUS_ENCAPS_SSLv3 },
   { "ENCAPS_TLSv1",  NESSUS_ENCAPS_TLSv1 },
 
-  { "NASL_LEVEL",	NASL_LEVEL },
+  { "NASL_LEVEL",	NASL_LEVEL }, /* deprecated: can be removed once openvas-plugins < 1.0.6 is deprecated */
   { "OPENVAS_NASL_LEVEL",	OPENVAS_NASL_LEVEL },
 
   { "TH_FIN", TH_FIN },
