@@ -193,27 +193,15 @@ typedef void(*script_register_func_t)(struct arglist*, const char *, const char*
 static tree_cell * script_elem(lex_ctxt* lexic, script_register_func_t script_register_func)
 { 
  struct arglist * script_infos = lexic->script_infos;
- char * lang = NULL;
- 
  char * str;
- char * dfl = "english";
- 
- if( lang == NULL )
- 	lang = dfl;
- 
- str = get_str_local_var_by_name(lexic, lang);
- 
 
- if(str == NULL){
- 	str = get_str_local_var_by_name(lexic, "english");
- 	if( str == NULL ){
-		str = get_str_var_by_num(lexic, 0);
- 		if( str == NULL )
-			return FAKE_CELL;
-			
-		}
-	    }
-	    
+ str = get_str_local_var_by_name(lexic, "english");
+ if( str == NULL ) {
+  str = get_str_var_by_num(lexic, 0);
+  if( str == NULL )
+   return FAKE_CELL;
+ }
+
  script_register_func(script_infos, str, NULL);	    
  return FAKE_CELL;
 }
@@ -330,6 +318,30 @@ tree_cell * script_require_keys(lex_ctxt * lexic)
  return FAKE_CELL;
 }
 
+tree_cell * script_mandatory_keys(lex_ctxt * lexic)
+{
+ struct arglist * script_infos  = lexic->script_infos;
+ 
+ char * keys = get_str_var_by_num(lexic, 0);
+ int i;
+ 
+ if(keys == NULL){
+ 	nasl_perror(lexic, "Argument error in function script_mandatory_keys()\n");
+	nasl_perror(lexic, "Function usage is : script_mandatory_keys(<name>)\n");
+	nasl_perror(lexic, "Where <name> is the name of a key\n");
+	return FAKE_CELL;
+	}
+  
+ for(i=0; keys != NULL;i++)
+ {
+  keys = get_str_var_by_num(lexic, i);
+  if(keys != NULL)
+  	plug_mandatory_key(script_infos, keys);
+ }
+ 
+ return FAKE_CELL;
+}
+
 tree_cell * script_exclude_keys(lex_ctxt * lexic)
 {
  struct arglist * script_infos = lexic->script_infos;
